from .connection import ActiveConnection as ActiveConnection
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.json import JSONEncoder as JSONEncoder
from typing import Any

WebSocketCommandHandler: Any
DOMAIN: str
URL: str
PENDING_MSG_PEAK: int
PENDING_MSG_PEAK_TIME: int
MAX_PENDING_MSG: int
ERR_ID_REUSE: str
ERR_INVALID_FORMAT: str
ERR_NOT_FOUND: str
ERR_NOT_SUPPORTED: str
ERR_HOME_ASSISTANT_ERROR: str
ERR_UNKNOWN_COMMAND: str
ERR_UNKNOWN_ERROR: str
ERR_UNAUTHORIZED: str
ERR_TIMEOUT: str
ERR_TEMPLATE_ERROR: str
TYPE_RESULT: str
CANCELLATION_ERRORS: Any
SIGNAL_WEBSOCKET_CONNECTED: str
SIGNAL_WEBSOCKET_DISCONNECTED: str
DATA_CONNECTIONS: Any
JSON_DUMP: Any



from homeassistant import core as core
from homeassistant.config import get_default_config_dir as get_default_config_dir
from homeassistant.exceptions import HomeAssistantError as HomeAssistantError
from homeassistant.helpers.check_config import async_check_ha_config_file as async_check_ha_config_file
from homeassistant.util.yaml import Secrets as Secrets
from typing import Any, Callable, Optional

REQUIREMENTS: Any
_LOGGER: Any
MOCKS: dict[str, tuple[str, Callable]]
PATCHES: dict[str, Any]
C_HEAD: str
ERROR_STR: str

def color(the_color: Any, *args: Any, reset: Optional[Any] = ...): ...
def run(script_args: list) -> int: ...
def check(config_dir: Any, secrets: bool = ...): ...
async def async_check_config(config_dir: Any): ...
def line_info(obj: Any, **kwargs: Any): ...
def dump_dict(layer: Any, indent_count: int = ..., listi: bool = ..., **kwargs: Any): ...



import abc
import asyncio
import voluptuous as vol
from .core import HomeAssistant as HomeAssistant, callback as callback
from .exceptions import HomeAssistantError as HomeAssistantError
from typing import Any

RESULT_TYPE_FORM: str
RESULT_TYPE_CREATE_ENTRY: str
RESULT_TYPE_ABORT: str
RESULT_TYPE_EXTERNAL_STEP: str
RESULT_TYPE_EXTERNAL_STEP_DONE: str
RESULT_TYPE_SHOW_PROGRESS: str
RESULT_TYPE_SHOW_PROGRESS_DONE: str
EVENT_DATA_ENTRY_FLOW_PROGRESSED: str

class FlowError(HomeAssistantError): ...
class UnknownHandler(FlowError): ...
class UnknownFlow(FlowError): ...
class UnknownStep(FlowError): ...

class AbortFlow(FlowError):
    reason: Any = ...
    description_placeholders: Any = ...
    def __init__(self, reason: str, description_placeholders: Union[dict, None]=...) -> None: ...

class FlowManager(abc.ABC, metaclass=abc.ABCMeta):
    hass: Any = ...
    _initializing: Any = ...
    _progress: Any = ...
    def __init__(self, hass: HomeAssistant) -> None: ...
    async def async_wait_init_flow_finish(self, handler: str) -> None: ...
    @abc.abstractmethod
    async def async_create_flow(self, handler_key: Any, *, context: Union[dict[str, Any], None]=..., data: Union[dict[str, Any], None]=...) -> FlowHandler: ...
    @abc.abstractmethod
    async def async_finish_flow(self, flow: FlowHandler, result: dict[str, Any]) -> dict[str, Any]: ...
    async def async_post_init(self, flow: FlowHandler, result: dict[str, Any]) -> None: ...
    def async_progress(self, include_uninitialized: bool=...) -> list[dict]: ...
    async def async_init(self, handler: str, *, context: Union[dict, None]=..., data: Any=...) -> Any: ...
    async def async_configure(self, flow_id: str, user_input: Union[dict, None]=...) -> Any: ...
    def async_abort(self, flow_id: str) -> None: ...
    async def _async_handle_step(self, flow: Any, step_id: str, user_input: Union[dict, None], step_done: Union[asyncio.Future, None]=...) -> dict: ...

class FlowHandler:
    cur_step: Union[dict[str, str], None] = ...
    flow_id: str = ...
    hass: HomeAssistant = ...
    handler: str = ...
    context: dict = ...
    init_step: str = ...
    VERSION: int = ...
    @property
    def source(self) -> Union[str, None]: ...
    @property
    def show_advanced_options(self) -> bool: ...
    def async_show_form(self, step_id: str, *, data_schema: vol.Schema=..., errors: Union[dict, None]=..., description_placeholders: Union[dict, None]=...) -> dict[str, Any]: ...
    def async_create_entry(self, title: str, data: dict, *, description: Union[str, None]=..., description_placeholders: Union[dict, None]=...) -> dict[str, Any]: ...
    def async_abort(self, reason: str, *, description_placeholders: Union[dict, None]=...) -> dict[str, Any]: ...
    def async_external_step(self, step_id: str, url: str, *, description_placeholders: Union[dict, None]=...) -> dict[str, Any]: ...
    def async_external_step_done(self, next_step_id: str) -> dict[str, Any]: ...
    def async_show_progress(self, step_id: str, progress_action: str, *, description_placeholders: Union[dict, None]=...) -> dict[str, Any]: ...
    def async_show_progress_done(self, next_step_id: str) -> dict[str, Any]: ...

def _create_abort_data(flow_id: str, handler: str, reason: str, description_placeholders: Union[dict, None]=...) -> dict[str, Any]: ...



from homeassistant.helpers import device_registry as dev_reg, entity_registry as ent_reg
from typing import Any

class PermissionLookup:
    entity_registry: ent_reg.EntityRegistry = ...
    device_registry: dev_reg.DeviceRegistry = ...
    def __init__(self, entity_registry: Any, device_registry: Any) -> None: ...
    def __lt__(self, other: Any) -> Any: ...
    def __le__(self, other: Any) -> Any: ...
    def __gt__(self, other: Any) -> Any: ...
    def __ge__(self, other: Any) -> Any: ...



from .const import BPUP_SUBS as BPUP_SUBS, DOMAIN as DOMAIN, HUB as HUB
from .entity import BondEntity as BondEntity
from .utils import BondDevice as BondDevice, BondHub as BondHub
from bond_api import BPUPSubscriptions as BPUPSubscriptions
from homeassistant.components.cover import CoverEntity as CoverEntity, DEVICE_CLASS_SHADE as DEVICE_CLASS_SHADE
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.entity import Entity as Entity
from typing import Any, Callable

async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry, async_add_entities: Callable[[list[Entity], bool], None]) -> None: ...

class BondCover(BondEntity, CoverEntity):
    _closed: Any = ...
    def __init__(self, hub: BondHub, device: BondDevice, bpup_subs: BPUPSubscriptions) -> None: ...
    def _apply_state(self, state: dict) -> None: ...
    @property
    def device_class(self) -> Union[str, None]: ...
    @property
    def is_closed(self) -> Union[bool, None]: ...
    async def async_open_cover(self, **kwargs: Any) -> None: ...
    async def async_close_cover(self, **kwargs: Any) -> None: ...
    async def async_stop_cover(self, **kwargs: Any) -> None: ...



from homeassistant.components.group import GroupIntegrationRegistry as GroupIntegrationRegistry
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback

def async_describe_on_off_states(hass: HomeAssistant, registry: GroupIntegrationRegistry) -> None: ...



from .const import CONF_INVERT as CONF_INVERT, CONF_RESET_AFTER as CONF_RESET_AFTER, CONF_STATE_ADDRESS as CONF_STATE_ADDRESS, CONF_SYNC_STATE as CONF_SYNC_STATE, CONTROLLER_MODES as CONTROLLER_MODES, ColorTempModes as ColorTempModes, KNX_ADDRESS as KNX_ADDRESS, PRESET_MODES as PRESET_MODES
from homeassistant.const import CONF_DEVICE_CLASS as CONF_DEVICE_CLASS, CONF_ENTITY_ID as CONF_ENTITY_ID, CONF_HOST as CONF_HOST, CONF_NAME as CONF_NAME, CONF_PORT as CONF_PORT, CONF_TYPE as CONF_TYPE
from typing import Any

ga_validator: Any
ga_list_validator: Any
ia_validator: Any
sync_state_validator: Any
sensor_type_validator: Any

class ConnectionSchema:
    CONF_KNX_LOCAL_IP: str = ...
    CONF_KNX_ROUTE_BACK: str = ...
    TUNNELING_SCHEMA: Any = ...
    ROUTING_SCHEMA: Any = ...

class BinarySensorSchema:
    CONF_STATE_ADDRESS: Any = ...
    CONF_SYNC_STATE: Any = ...
    CONF_INVERT: Any = ...
    CONF_IGNORE_INTERNAL_STATE: str = ...
    CONF_CONTEXT_TIMEOUT: str = ...
    CONF_RESET_AFTER: Any = ...
    DEFAULT_NAME: str = ...
    SCHEMA: Any = ...

class ClimateSchema:
    CONF_SETPOINT_SHIFT_ADDRESS: str = ...
    CONF_SETPOINT_SHIFT_STATE_ADDRESS: str = ...
    CONF_SETPOINT_SHIFT_MODE: str = ...
    CONF_SETPOINT_SHIFT_MAX: str = ...
    CONF_SETPOINT_SHIFT_MIN: str = ...
    CONF_TEMPERATURE_ADDRESS: str = ...
    CONF_TEMPERATURE_STEP: str = ...
    CONF_TARGET_TEMPERATURE_ADDRESS: str = ...
    CONF_TARGET_TEMPERATURE_STATE_ADDRESS: str = ...
    CONF_OPERATION_MODE_ADDRESS: str = ...
    CONF_OPERATION_MODE_STATE_ADDRESS: str = ...
    CONF_CONTROLLER_STATUS_ADDRESS: str = ...
    CONF_CONTROLLER_STATUS_STATE_ADDRESS: str = ...
    CONF_CONTROLLER_MODE_ADDRESS: str = ...
    CONF_CONTROLLER_MODE_STATE_ADDRESS: str = ...
    CONF_HEAT_COOL_ADDRESS: str = ...
    CONF_HEAT_COOL_STATE_ADDRESS: str = ...
    CONF_OPERATION_MODE_FROST_PROTECTION_ADDRESS: str = ...
    CONF_OPERATION_MODE_NIGHT_ADDRESS: str = ...
    CONF_OPERATION_MODE_COMFORT_ADDRESS: str = ...
    CONF_OPERATION_MODE_STANDBY_ADDRESS: str = ...
    CONF_OPERATION_MODES: str = ...
    CONF_CONTROLLER_MODES: str = ...
    CONF_ON_OFF_ADDRESS: str = ...
    CONF_ON_OFF_STATE_ADDRESS: str = ...
    CONF_ON_OFF_INVERT: str = ...
    CONF_MIN_TEMP: str = ...
    CONF_MAX_TEMP: str = ...
    CONF_CREATE_TEMPERATURE_SENSORS: str = ...
    DEFAULT_NAME: str = ...
    DEFAULT_SETPOINT_SHIFT_MODE: str = ...
    DEFAULT_SETPOINT_SHIFT_MAX: int = ...
    DEFAULT_SETPOINT_SHIFT_MIN: int = ...
    DEFAULT_TEMPERATURE_STEP: float = ...
    DEFAULT_ON_OFF_INVERT: bool = ...
    SCHEMA: Any = ...

class CoverSchema:
    CONF_MOVE_LONG_ADDRESS: str = ...
    CONF_MOVE_SHORT_ADDRESS: str = ...
    CONF_STOP_ADDRESS: str = ...
    CONF_POSITION_ADDRESS: str = ...
    CONF_POSITION_STATE_ADDRESS: str = ...
    CONF_ANGLE_ADDRESS: str = ...
    CONF_ANGLE_STATE_ADDRESS: str = ...
    CONF_TRAVELLING_TIME_DOWN: str = ...
    CONF_TRAVELLING_TIME_UP: str = ...
    CONF_INVERT_POSITION: str = ...
    CONF_INVERT_ANGLE: str = ...
    DEFAULT_TRAVEL_TIME: int = ...
    DEFAULT_NAME: str = ...
    SCHEMA: Any = ...

class ExposeSchema:
    CONF_KNX_EXPOSE_TYPE: Any = ...
    CONF_KNX_EXPOSE_ATTRIBUTE: str = ...
    CONF_KNX_EXPOSE_DEFAULT: str = ...
    EXPOSE_TIME_TYPES: Any = ...
    EXPOSE_TIME_SCHEMA: Any = ...
    EXPOSE_SENSOR_SCHEMA: Any = ...
    SCHEMA: Any = ...

class FanSchema:
    CONF_STATE_ADDRESS: Any = ...
    CONF_OSCILLATION_ADDRESS: str = ...
    CONF_OSCILLATION_STATE_ADDRESS: str = ...
    CONF_MAX_STEP: str = ...
    DEFAULT_NAME: str = ...
    SCHEMA: Any = ...

class LightSchema:
    CONF_STATE_ADDRESS: Any = ...
    CONF_BRIGHTNESS_ADDRESS: str = ...
    CONF_BRIGHTNESS_STATE_ADDRESS: str = ...
    CONF_COLOR_ADDRESS: str = ...
    CONF_COLOR_STATE_ADDRESS: str = ...
    CONF_COLOR_TEMP_ADDRESS: str = ...
    CONF_COLOR_TEMP_STATE_ADDRESS: str = ...
    CONF_COLOR_TEMP_MODE: str = ...
    CONF_RGBW_ADDRESS: str = ...
    CONF_RGBW_STATE_ADDRESS: str = ...
    CONF_MIN_KELVIN: str = ...
    CONF_MAX_KELVIN: str = ...
    DEFAULT_NAME: str = ...
    DEFAULT_COLOR_TEMP_MODE: str = ...
    DEFAULT_MIN_KELVIN: int = ...
    DEFAULT_MAX_KELVIN: int = ...
    CONF_INDIVIDUAL_COLORS: str = ...
    CONF_RED: str = ...
    CONF_GREEN: str = ...
    CONF_BLUE: str = ...
    CONF_WHITE: str = ...
    COLOR_SCHEMA: Any = ...
    SCHEMA: Any = ...

class NotifySchema:
    DEFAULT_NAME: str = ...
    SCHEMA: Any = ...

class SceneSchema:
    CONF_SCENE_NUMBER: str = ...
    DEFAULT_NAME: str = ...
    SCHEMA: Any = ...

class SensorSchema:
    CONF_ALWAYS_CALLBACK: str = ...
    CONF_STATE_ADDRESS: Any = ...
    CONF_SYNC_STATE: Any = ...
    DEFAULT_NAME: str = ...
    SCHEMA: Any = ...

class SwitchSchema:
    CONF_INVERT: Any = ...
    CONF_STATE_ADDRESS: Any = ...
    DEFAULT_NAME: str = ...
    SCHEMA: Any = ...

class WeatherSchema:
    CONF_SYNC_STATE: Any = ...
    CONF_KNX_TEMPERATURE_ADDRESS: str = ...
    CONF_KNX_BRIGHTNESS_SOUTH_ADDRESS: str = ...
    CONF_KNX_BRIGHTNESS_EAST_ADDRESS: str = ...
    CONF_KNX_BRIGHTNESS_WEST_ADDRESS: str = ...
    CONF_KNX_BRIGHTNESS_NORTH_ADDRESS: str = ...
    CONF_KNX_WIND_SPEED_ADDRESS: str = ...
    CONF_KNX_WIND_BEARING_ADDRESS: str = ...
    CONF_KNX_RAIN_ALARM_ADDRESS: str = ...
    CONF_KNX_FROST_ALARM_ADDRESS: str = ...
    CONF_KNX_WIND_ALARM_ADDRESS: str = ...
    CONF_KNX_DAY_NIGHT_ADDRESS: str = ...
    CONF_KNX_AIR_PRESSURE_ADDRESS: str = ...
    CONF_KNX_HUMIDITY_ADDRESS: str = ...
    CONF_KNX_CREATE_SENSORS: str = ...
    DEFAULT_NAME: str = ...
    SCHEMA: Any = ...



from .const import DATA_CLIENT as DATA_CLIENT, DATA_UNSUBSCRIBE as DATA_UNSUBSCRIBE, DOMAIN as DOMAIN
from .discovery import ZwaveDiscoveryInfo as ZwaveDiscoveryInfo
from .entity import ZWaveBaseEntity as ZWaveBaseEntity
from homeassistant.components.sensor import DEVICE_CLASS_BATTERY as DEVICE_CLASS_BATTERY, DEVICE_CLASS_ENERGY as DEVICE_CLASS_ENERGY, DEVICE_CLASS_ILLUMINANCE as DEVICE_CLASS_ILLUMINANCE, DEVICE_CLASS_POWER as DEVICE_CLASS_POWER, SensorEntity as SensorEntity
from homeassistant.config_entries import ConfigEntry as ConfigEntry
from homeassistant.const import DEVICE_CLASS_HUMIDITY as DEVICE_CLASS_HUMIDITY, DEVICE_CLASS_TEMPERATURE as DEVICE_CLASS_TEMPERATURE, TEMP_CELSIUS as TEMP_CELSIUS, TEMP_FAHRENHEIT as TEMP_FAHRENHEIT
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.helpers.dispatcher import async_dispatcher_connect as async_dispatcher_connect
from typing import Any, Callable
from zwave_js_server.client import Client as ZwaveClient

LOGGER: Any

async def async_setup_entry(hass: HomeAssistant, config_entry: ConfigEntry, async_add_entities: Callable) -> None: ...

class ZwaveSensorBase(ZWaveBaseEntity, SensorEntity):
    _name: Any = ...
    _device_class: Any = ...
    def __init__(self, config_entry: ConfigEntry, client: ZwaveClient, info: ZwaveDiscoveryInfo) -> None: ...
    def _get_device_class(self) -> Union[str, None]: ...
    @property
    def device_class(self) -> Union[str, None]: ...
    @property
    def entity_registry_enabled_default(self) -> bool: ...
    @property
    def force_update(self) -> bool: ...

class ZWaveStringSensor(ZwaveSensorBase):
    @property
    def state(self) -> Union[str, None]: ...
    @property
    def unit_of_measurement(self) -> Union[str, None]: ...

class ZWaveNumericSensor(ZwaveSensorBase):
    _name: Any = ...
    def __init__(self, config_entry: ConfigEntry, client: ZwaveClient, info: ZwaveDiscoveryInfo) -> None: ...
    @property
    def state(self) -> float: ...
    @property
    def unit_of_measurement(self) -> Union[str, None]: ...

class ZWaveListSensor(ZwaveSensorBase):
    _name: Any = ...
    def __init__(self, config_entry: ConfigEntry, client: ZwaveClient, info: ZwaveDiscoveryInfo) -> None: ...
    @property
    def state(self) -> Union[str, None]: ...
    @property
    def extra_state_attributes(self) -> Union[dict[str, str], None]: ...

class ZWaveConfigParameterSensor(ZwaveSensorBase):
    _name: Any = ...
    _primary_value: Any = ...
    def __init__(self, config_entry: ConfigEntry, client: ZwaveClient, info: ZwaveDiscoveryInfo) -> None: ...
    @property
    def state(self) -> Union[str, None]: ...
    @property
    def extra_state_attributes(self) -> Union[dict[str, str], None]: ...



from .const import KEY_AUTHENTICATED as KEY_AUTHENTICATED, KEY_HASS_REFRESH_TOKEN_ID as KEY_HASS_REFRESH_TOKEN_ID, KEY_HASS_USER as KEY_HASS_USER
from homeassistant.core import callback as callback
from typing import Any

_LOGGER: Any
DATA_API_PASSWORD: str
DATA_SIGN_SECRET: str
SIGN_QUERY_PARAM: str

def async_sign_path(hass: Any, refresh_token_id: Any, path: Any, expiration: Any): ...
def setup_auth(hass: Any, app: Any): ...



from typing import Any

_LOGGER: Any

def is_virtual_env() -> bool: ...
def is_docker_env() -> bool: ...
def is_installed(package: str) -> bool: ...
def install_package(package: str, upgrade: bool=..., target: Union[str, None]=..., constraints: Union[str, None]=..., find_links: Union[str, None]=..., no_cache_dir: Union[bool, None]=...) -> bool: ...
async def async_get_user_site(deps_dir: str) -> str: ...



from homeassistant.components.sensor import PLATFORM_SCHEMA as PLATFORM_SCHEMA, SensorEntity as SensorEntity
from homeassistant.const import CONF_RESOURCES as CONF_RESOURCES, CONF_TYPE as CONF_TYPE, DATA_GIBIBYTES as DATA_GIBIBYTES, DATA_MEBIBYTES as DATA_MEBIBYTES, DATA_RATE_MEGABYTES_PER_SECOND as DATA_RATE_MEGABYTES_PER_SECOND, PERCENTAGE as PERCENTAGE, STATE_OFF as STATE_OFF, STATE_ON as STATE_ON, TEMP_CELSIUS as TEMP_CELSIUS
from homeassistant.util import slugify as slugify
from typing import Any, Optional

_LOGGER: Any
CONF_ARG: str
CPU_ICON: str
SENSOR_TYPES: Any

def check_required_arg(value: Any): ...

IO_COUNTER: Any
IF_ADDRS_FAMILY: Any
CPU_SENSOR_PREFIXES: Any

def setup_platform(hass: Any, config: Any, add_entities: Any, discovery_info: Optional[Any] = ...) -> None: ...

class SystemMonitorSensor(SensorEntity):
    _name: Any = ...
    _unique_id: Any = ...
    argument: Any = ...
    type: Any = ...
    _state: Any = ...
    _unit_of_measurement: Any = ...
    _available: bool = ...
    _last_value: Any = ...
    _last_update_time: Any = ...
    def __init__(self, sensor_type: Any, argument: str = ...) -> None: ...
    @property
    def name(self): ...
    @property
    def unique_id(self): ...
    @property
    def device_class(self): ...
    @property
    def icon(self): ...
    @property
    def state(self): ...
    @property
    def unit_of_measurement(self): ...
    @property
    def available(self): ...
    def update(self) -> None: ...
    @staticmethod
    def read_cpu_temperature(): ...



from .const import DOMAIN as DOMAIN
from .knx_entity import KnxEntity as KnxEntity
from .schema import LightSchema as LightSchema
from homeassistant.components.light import ATTR_BRIGHTNESS as ATTR_BRIGHTNESS, ATTR_COLOR_TEMP as ATTR_COLOR_TEMP, ATTR_HS_COLOR as ATTR_HS_COLOR, ATTR_WHITE_VALUE as ATTR_WHITE_VALUE, LightEntity as LightEntity, SUPPORT_BRIGHTNESS as SUPPORT_BRIGHTNESS, SUPPORT_COLOR as SUPPORT_COLOR, SUPPORT_COLOR_TEMP as SUPPORT_COLOR_TEMP, SUPPORT_WHITE_VALUE as SUPPORT_WHITE_VALUE
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.entity import Entity as Entity
from homeassistant.helpers.typing import ConfigType as ConfigType, DiscoveryInfoType as DiscoveryInfoType
from typing import Any, Callable, Iterable
from xknx.devices import Light as XknxLight

DEFAULT_COLOR: Any
DEFAULT_BRIGHTNESS: int
DEFAULT_WHITE_VALUE: int

async def async_setup_platform(hass: HomeAssistant, config: ConfigType, async_add_entities: Callable[[Iterable[Entity]], None], discovery_info: Union[DiscoveryInfoType, None]=...) -> None: ...

class KNXLight(KnxEntity, LightEntity):
    _device: Any
    _min_kelvin: Any = ...
    _max_kelvin: Any = ...
    _min_mireds: Any = ...
    _max_mireds: Any = ...
    def __init__(self, device: XknxLight) -> None: ...
    @property
    def brightness(self) -> Union[int, None]: ...
    @property
    def hs_color(self) -> Union[tuple[float, float], None]: ...
    @property
    def _hsv_color(self) -> Union[tuple[float, float, float], None]: ...
    @property
    def white_value(self) -> Union[int, None]: ...
    @property
    def color_temp(self) -> Union[int, None]: ...
    @property
    def min_mireds(self) -> int: ...
    @property
    def max_mireds(self) -> int: ...
    @property
    def effect_list(self) -> Union[list[str], None]: ...
    @property
    def effect(self) -> Union[str, None]: ...
    @property
    def is_on(self) -> bool: ...
    @property
    def supported_features(self) -> int: ...
    async def async_turn_on(self, **kwargs: Any) -> None: ...
    async def async_turn_off(self, **kwargs: Any) -> None: ...



from .models import HaServiceBrowser as HaServiceBrowser, HaZeroconf as HaZeroconf
from .usage import install_multiple_zeroconf_catcher as install_multiple_zeroconf_catcher
from homeassistant import util as util
from homeassistant.const import EVENT_HOMEASSISTANT_START as EVENT_HOMEASSISTANT_START, EVENT_HOMEASSISTANT_STARTED as EVENT_HOMEASSISTANT_STARTED, EVENT_HOMEASSISTANT_STOP as EVENT_HOMEASSISTANT_STOP, __version__ as __version__
from homeassistant.core import Event as Event, HomeAssistant as HomeAssistant
from homeassistant.helpers.network import NoURLAvailableError as NoURLAvailableError, get_url as get_url
from homeassistant.helpers.singleton import singleton as singleton
from homeassistant.loader import async_get_homekit as async_get_homekit, async_get_zeroconf as async_get_zeroconf
from typing import Any, TypedDict
from zeroconf import ServiceInfo, Zeroconf as Zeroconf

_LOGGER: Any
DOMAIN: str
ZEROCONF_TYPE: str
HOMEKIT_TYPES: Any
CONF_DEFAULT_INTERFACE: str
CONF_IPV6: str
DEFAULT_DEFAULT_INTERFACE: bool
DEFAULT_IPV6: bool
HOMEKIT_PAIRED_STATUS_FLAG: str
HOMEKIT_MODEL: str
MAX_PROPERTY_VALUE_LEN: int
MAX_NAME_LEN: int
CONFIG_SCHEMA: Any

class HaServiceInfo(TypedDict):
    host: str
    port: Union[int, None]
    hostname: str
    type: str
    name: str
    properties: dict[str, Any]

async def async_get_instance(hass: HomeAssistant) -> HaZeroconf: ...
async def _async_get_instance(hass: HomeAssistant, **zcargs: Any) -> HaZeroconf: ...
async def async_setup(hass: HomeAssistant, config: dict) -> bool: ...
def _register_hass_zc_service(hass: HomeAssistant, zeroconf: HaZeroconf, uuid: str) -> None: ...
async def _async_start_zeroconf_browser(hass: HomeAssistant, zeroconf: HaZeroconf) -> None: ...
def handle_homekit(hass: HomeAssistant, homekit_models: dict[str, str], info: HaServiceInfo) -> bool: ...
def info_from_service(service: ServiceInfo) -> Union[HaServiceInfo, None]: ...
def _suppress_invalid_properties(properties: dict) -> None: ...
def _truncate_location_name_to_valid(location_name: str) -> str: ...



from . import ATTR_FAN_SPEED as ATTR_FAN_SPEED, DOMAIN as DOMAIN, SERVICE_PAUSE as SERVICE_PAUSE, SERVICE_RETURN_TO_BASE as SERVICE_RETURN_TO_BASE, SERVICE_SET_FAN_SPEED as SERVICE_SET_FAN_SPEED, SERVICE_START as SERVICE_START, SERVICE_STOP as SERVICE_STOP, STATE_CLEANING as STATE_CLEANING, STATE_DOCKED as STATE_DOCKED, STATE_RETURNING as STATE_RETURNING
from homeassistant.const import ATTR_ENTITY_ID as ATTR_ENTITY_ID, SERVICE_TURN_OFF as SERVICE_TURN_OFF, SERVICE_TURN_ON as SERVICE_TURN_ON, STATE_IDLE as STATE_IDLE, STATE_OFF as STATE_OFF, STATE_ON as STATE_ON, STATE_PAUSED as STATE_PAUSED
from homeassistant.core import Context as Context, State as State
from homeassistant.helpers.typing import HomeAssistantType as HomeAssistantType
from typing import Any, Iterable

_LOGGER: Any
VALID_STATES_TOGGLE: Any
VALID_STATES_STATE: Any

async def _async_reproduce_state(hass: HomeAssistantType, state: State, *, context: Union[Context, None]=..., reproduce_options: Union[dict[str, Any], None]=...) -> None: ...
async def async_reproduce_states(hass: HomeAssistantType, states: Iterable[State], *, context: Union[Context, None]=..., reproduce_options: Union[dict[str, Any], None]=...) -> None: ...



from . import AUTH_PROVIDERS as AUTH_PROVIDERS, AUTH_PROVIDER_SCHEMA as AUTH_PROVIDER_SCHEMA, AuthProvider as AuthProvider, LoginFlow as LoginFlow
from ..models import Credentials as Credentials, UserMeta as UserMeta
from homeassistant.core import callback as callback
from homeassistant.exceptions import HomeAssistantError as HomeAssistantError
from typing import Any

USER_SCHEMA: Any
CONFIG_SCHEMA: Any

class InvalidAuthError(HomeAssistantError): ...

class ExampleAuthProvider(AuthProvider):
    async def async_login_flow(self, context: Union[dict, None]) -> LoginFlow: ...
    def async_validate_login(self, username: str, password: str) -> None: ...
    async def async_get_or_create_credentials(self, flow_result: dict[str, str]) -> Credentials: ...
    async def async_user_meta_for_credentials(self, credentials: Credentials) -> UserMeta: ...

class ExampleLoginFlow(LoginFlow):
    async def async_step_init(self, user_input: Union[dict[str, str], None]=...) -> dict[str, Any]: ...



import astral
import datetime
from homeassistant.const import SUN_EVENT_SUNRISE as SUN_EVENT_SUNRISE, SUN_EVENT_SUNSET as SUN_EVENT_SUNSET
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.loader import bind_hass as bind_hass

DATA_LOCATION_CACHE: str

def get_astral_location(hass: HomeAssistant) -> astral.Location: ...
def get_astral_event_next(hass: HomeAssistant, event: str, utc_point_in_time: Union[datetime.datetime, None]=..., offset: Union[datetime.timedelta, None]=...) -> datetime.datetime: ...
def get_location_astral_event_next(location: astral.Location, event: str, utc_point_in_time: Union[datetime.datetime, None]=..., offset: Union[datetime.timedelta, None]=...) -> datetime.datetime: ...
def get_astral_event_date(hass: HomeAssistant, event: str, date: Union[datetime.date, datetime.datetime, None]=...) -> Union[datetime.datetime, None]: ...
def is_up(hass: HomeAssistant, utc_point_in_time: Union[datetime.datetime, None]=...) -> bool: ...



from .const import DOMAIN as DOMAIN
from .knx_entity import KnxEntity as KnxEntity
from homeassistant.components.scene import Scene as Scene
from homeassistant.core import HomeAssistant as HomeAssistant
from homeassistant.helpers.entity import Entity as Entity
from homeassistant.helpers.typing import ConfigType as ConfigType, DiscoveryInfoType as DiscoveryInfoType
from typing import Any, Callable, Iterable
from xknx.devices import Scene as XknxScene

async def async_setup_platform(hass: HomeAssistant, config: ConfigType, async_add_entities: Callable[[Iterable[Entity]], None], discovery_info: Union[DiscoveryInfoType, None]=...) -> None: ...

class KNXScene(KnxEntity, Scene):
    _device: Any
    def __init__(self, device: XknxScene) -> None: ...
    async def async_activate(self, **kwargs: Any) -> None: ...



from .const import CONNECTION_TIMEOUT as CONNECTION_TIMEOUT, DEFAULT_DEVICE_NAME as DEFAULT_DEVICE_NAME, DEFAULT_NOTIFY_SERVICE_NAME as DEFAULT_NOTIFY_SERVICE_NAME, DOMAIN as DOMAIN
from homeassistant import config_entries as config_entries
from homeassistant.components import ssdp as ssdp
from homeassistant.const import CONF_NAME as CONF_NAME, CONF_PASSWORD as CONF_PASSWORD, CONF_RECIPIENT as CONF_RECIPIENT, CONF_URL as CONF_URL, CONF_USERNAME as CONF_USERNAME
from homeassistant.core import callback as callback
from typing import Any

_LOGGER: Any

class ConfigFlowHandler(config_entries.ConfigFlow):
    VERSION: int = ...
    CONNECTION_CLASS: Any = ...
    @staticmethod
    def async_get_options_flow(config_entry: config_entries.ConfigEntry) -> OptionsFlowHandler: ...
    async def _async_show_user_form(self, user_input: Union[dict[str, Any], None]=..., errors: Union[dict[str, str], None]=...) -> dict[str, Any]: ...
    async def async_step_import(self, user_input: Union[dict[str, Any], None]=...) -> dict[str, Any]: ...
    def _already_configured(self, user_input: dict[str, Any]) -> bool: ...
    async def async_step_user(self, user_input: Union[dict[str, Any], None]=...) -> dict[str, Any]: ...
    async def async_step_ssdp(self, discovery_info: dict[str, Any]) -> dict[str, Any]: ...

class OptionsFlowHandler(config_entries.OptionsFlow):
    config_entry: Any = ...
    def __init__(self, config_entry: config_entries.ConfigEntry) -> None: ...
    async def async_step_init(self, user_input: Union[dict[str, Any], None]=...) -> dict[str, Any]: ...



def ordered_list_item_to_percentage(ordered_list: list[str], item: str) -> int: ...
def percentage_to_ordered_list_item(ordered_list: list[str], percentage: int) -> str: ...
def ranged_value_to_percentage(low_high_range: tuple[float, float], value: float) -> int: ...
def percentage_to_ranged_value(low_high_range: tuple[float, float], percentage: int) -> float: ...
def states_in_range(low_high_range: tuple[float, float]) -> float: ...
def int_states_in_range(low_high_range: tuple[float, float]) -> int: ...



from homeassistant import config_entries as config_entries
from homeassistant.core import HomeAssistant as HomeAssistant
from typing import Any, Awaitable, Callable, Union

DiscoveryFunctionType = Callable[[], Union[Awaitable[bool], bool]]

class DiscoveryFlowHandler(config_entries.ConfigFlow):
    VERSION: int = ...
    _domain: Any = ...
    _title: Any = ...
    _discovery_function: Any = ...
    CONNECTION_CLASS: Any = ...
    def __init__(self, domain: str, title: str, discovery_function: DiscoveryFunctionType, connection_class: str) -> None: ...
    async def async_step_user(self, user_input: Union[dict[str, Any], None]=...) -> dict[str, Any]: ...
    async def async_step_confirm(self, user_input: Union[dict[str, Any], None]=...) -> dict[str, Any]: ...
    async def async_step_discovery(self, discovery_info: dict[str, Any]) -> dict[str, Any]: ...
    async_step_zeroconf: Any = ...
    async_step_ssdp: Any = ...
    async_step_mqtt: Any = ...
    async_step_homekit: Any = ...
    async_step_dhcp: Any = ...
    async def async_step_import(self, _: Union[dict[str, Any], None]) -> dict[str, Any]: ...

def register_discovery_flow(domain: str, title: str, discovery_function: DiscoveryFunctionType, connection_class: str) -> None: ...

class WebhookFlowHandler(config_entries.ConfigFlow):
    VERSION: int = ...
    _domain: Any = ...
    _title: Any = ...
    _description_placeholder: Any = ...
    _allow_multiple: Any = ...
    def __init__(self, domain: str, title: str, description_placeholder: dict, allow_multiple: bool) -> None: ...
    async def async_step_user(self, user_input: Union[dict[str, Any], None]=...) -> dict[str, Any]: ...

def register_webhook_flow(domain: str, title: str, description_placeholder: dict, allow_multiple: bool=...) -> None: ...
async def webhook_async_remove_entry(hass: HomeAssistant, entry: config_entries.ConfigEntry) -> None: ...



from . import AUTH_PROVIDERS as AUTH_PROVIDERS, AUTH_PROVIDER_SCHEMA as AUTH_PROVIDER_SCHEMA, AuthProvider as AuthProvider, LoginFlow as LoginFlow
from ..models import Credentials as Credentials, UserMeta as UserMeta
from homeassistant.core import callback as callback
from homeassistant.exceptions import HomeAssistantError as HomeAssistantError
from typing import Any

AUTH_PROVIDER_TYPE: str
CONF_API_PASSWORD: str
CONFIG_SCHEMA: Any
LEGACY_USER_NAME: str

class InvalidAuthError(HomeAssistantError): ...

class LegacyApiPasswordAuthProvider(AuthProvider):
    DEFAULT_TITLE: str = ...
    @property
    def api_password(self) -> str: ...
    async def async_login_flow(self, context: Union[dict, None]) -> LoginFlow: ...
    def async_validate_login(self, password: str) -> None: ...
    async def async_get_or_create_credentials(self, flow_result: dict[str, str]) -> Credentials: ...
    async def async_user_meta_for_credentials(self, credentials: Credentials) -> UserMeta: ...

class LegacyLoginFlow(LoginFlow):
    async def async_step_init(self, user_input: Union[dict[str, str], None]=...) -> dict[str, Any]: ...



from .const import DOMAIN as DOMAIN, KNX_ADDRESS as KNX_ADDRESS, SupportedPlatforms as SupportedPlatforms
from .expose import KNXExposeSensor as KNXExposeSensor, KNXExposeTime as KNXExposeTime, create_knx_exposure as create_knx_exposure
from .factory import create_knx_device as create_knx_device
from .schema import BinarySensorSchema as BinarySensorSchema, ClimateSchema as ClimateSchema, ConnectionSchema as ConnectionSchema, CoverSchema as CoverSchema, ExposeSchema as ExposeSchema, FanSchema as FanSchema, LightSchema as LightSchema, NotifySchema as NotifySchema, SceneSchema as SceneSchema, SensorSchema as SensorSchema, SwitchSchema as SwitchSchema, WeatherSchema as WeatherSchema, ga_validator as ga_validator, ia_validator as ia_validator, sensor_type_validator as sensor_type_validator
from homeassistant.const import CONF_HOST as CONF_HOST, CONF_PORT as CONF_PORT, EVENT_HOMEASSISTANT_STOP as EVENT_HOMEASSISTANT_STOP, SERVICE_RELOAD as SERVICE_RELOAD
from homeassistant.core import Event as Event, HomeAssistant as HomeAssistant, ServiceCall as ServiceCall
from homeassistant.exceptions import HomeAssistantError as HomeAssistantError
from homeassistant.helpers import discovery as discovery
from homeassistant.helpers.entity_platform import async_get_platforms as async_get_platforms
from homeassistant.helpers.reload import async_integration_yaml_config as async_integration_yaml_config
from homeassistant.helpers.service import async_register_admin_service as async_register_admin_service
from homeassistant.helpers.typing import ConfigType as ConfigType
from typing import Any
from xknx.core.telegram_queue import TelegramQueue as TelegramQueue
from xknx.io import ConnectionConfig
from xknx.telegram import Telegram

_LOGGER: Any
CONF_KNX_CONFIG: str
CONF_KNX_ROUTING: str
CONF_KNX_TUNNELING: str
CONF_KNX_FIRE_EVENT: str
CONF_KNX_EVENT_FILTER: str
CONF_KNX_INDIVIDUAL_ADDRESS: str
CONF_KNX_MCAST_GRP: str
CONF_KNX_MCAST_PORT: str
CONF_KNX_STATE_UPDATER: str
CONF_KNX_RATE_LIMIT: str
CONF_KNX_EXPOSE: str
SERVICE_KNX_SEND: str
SERVICE_KNX_ATTR_PAYLOAD: str
SERVICE_KNX_ATTR_TYPE: str
SERVICE_KNX_ATTR_REMOVE: str
SERVICE_KNX_EVENT_REGISTER: str
SERVICE_KNX_EXPOSURE_REGISTER: str
SERVICE_KNX_READ: str
CONFIG_SCHEMA: Any
SERVICE_KNX_SEND_SCHEMA: Any
SERVICE_KNX_READ_SCHEMA: Any
SERVICE_KNX_EVENT_REGISTER_SCHEMA: Any
SERVICE_KNX_EXPOSURE_REGISTER_SCHEMA: Any

async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool: ...

class KNXModule:
    hass: Any = ...
    config: Any = ...
    connected: bool = ...
    exposures: Any = ...
    service_exposures: Any = ...
    _knx_event_callback: Any = ...
    def __init__(self, hass: HomeAssistant, config: ConfigType) -> None: ...
    xknx: Any = ...
    def init_xknx(self) -> None: ...
    async def start(self) -> None: ...
    async def stop(self, event: Event) -> None: ...
    def config_file(self) -> Union[str, None]: ...
    def connection_config(self) -> ConnectionConfig: ...
    def connection_config_routing(self) -> ConnectionConfig: ...
    def connection_config_tunneling(self) -> ConnectionConfig: ...
    async def telegram_received_cb(self, telegram: Telegram) -> None: ...
    def register_callback(self) -> TelegramQueue.Callback: ...
    async def service_event_register_modify(self, call: ServiceCall) -> None: ...
    async def service_exposure_register_modify(self, call: ServiceCall) -> None: ...
    async def service_send_to_knx_bus(self, call: ServiceCall) -> None: ...
    async def service_read_to_knx_bus(self, call: ServiceCall) -> None: ...



from .addon import AddonError as AddonError, AddonManager as AddonManager, get_addon_manager as get_addon_manager
from .const import CONF_ADDON_DEVICE as CONF_ADDON_DEVICE, CONF_ADDON_NETWORK_KEY as CONF_ADDON_NETWORK_KEY, CONF_INTEGRATION_CREATED_ADDON as CONF_INTEGRATION_CREATED_ADDON, CONF_NETWORK_KEY as CONF_NETWORK_KEY, CONF_USB_PATH as CONF_USB_PATH, CONF_USE_ADDON as CONF_USE_ADDON, DOMAIN as DOMAIN
from homeassistant import config_entries as config_entries, exceptions as exceptions
from homeassistant.components.hassio import is_hassio as is_hassio
from homeassistant.const import CONF_URL as CONF_URL
from homeassistant.core import HomeAssistant as HomeAssistant, callback as callback
from homeassistant.data_entry_flow import AbortFlow as AbortFlow
from homeassistant.helpers.aiohttp_client import async_get_clientsession as async_get_clientsession
from typing import Any
from zwave_js_server.version import VersionInfo as VersionInfo

_LOGGER: Any
DEFAULT_URL: str
TITLE: str
ADDON_SETUP_TIMEOUT: int
ADDON_SETUP_TIMEOUT_ROUNDS: int
SERVER_VERSION_TIMEOUT: int
ON_SUPERVISOR_SCHEMA: Any
STEP_USER_DATA_SCHEMA: Any

async def validate_input(hass: HomeAssistant, user_input: dict) -> VersionInfo: ...
async def async_get_version_info(hass: HomeAssistant, ws_address: str) -> VersionInfo: ...

class ConfigFlow(config_entries.ConfigFlow):
    VERSION: int = ...
    CONNECTION_CLASS: Any = ...
    network_key: Any = ...
    usb_path: Any = ...
    use_addon: bool = ...
    ws_address: Any = ...
    integration_created_addon: bool = ...
    install_task: Any = ...
    start_task: Any = ...
    def __init__(self) -> None: ...
    async def async_step_user(self, user_input: Union[dict[str, Any], None]=...) -> dict[str, Any]: ...
    async def async_step_manual(self, user_input: Union[dict[str, Any], None]=...) -> dict[str, Any]: ...
    async def async_step_hassio(self, discovery_info: dict[str, Any]) -> dict[str, Any]: ...
    async def async_step_hassio_confirm(self, user_input: Union[dict[str, Any], None]=...) -> dict[str, Any]: ...
    def _async_create_entry_from_vars(self) -> dict[str, Any]: ...
    async def async_step_on_supervisor(self, user_input: Union[dict[str, Any], None]=...) -> dict[str, Any]: ...
    async def async_step_install_addon(self, user_input: Union[dict[str, Any], None]=...) -> dict[str, Any]: ...
    async def async_step_install_failed(self, user_input: Union[dict[str, Any], None]=...) -> dict[str, Any]: ...
    async def async_step_configure_addon(self, user_input: Union[dict[str, Any], None]=...) -> dict[str, Any]: ...
    async def async_step_start_addon(self, user_input: Union[dict[str, Any], None]=...) -> dict[str, Any]: ...
    async def async_step_start_failed(self, user_input: Union[dict[str, Any], None]=...) -> dict[str, Any]: ...
    async def _async_start_addon(self) -> None: ...
    async def async_step_finish_addon_setup(self, user_input: Union[dict[str, Any], None]=...) -> dict[str, Any]: ...
    async def _async_get_addon_info(self) -> dict: ...
    async def _async_is_addon_running(self) -> bool: ...
    async def _async_is_addon_installed(self) -> bool: ...
    async def _async_get_addon_config(self) -> dict: ...
    async def _async_set_addon_config(self, config: dict) -> None: ...
    async def _async_install_addon(self) -> None: ...
    async def _async_get_addon_discovery_info(self) -> dict: ...

class CannotConnect(exceptions.HomeAssistantError): ...

class InvalidInput(exceptions.HomeAssistantError):
    error: Any = ...
    def __init__(self, error: str) -> None: ...
